@@ -24,4 +24,4 @@ class SuperCSVConfig(AppConfig):
     }
 
     def ready(self):
-        from . import signals  # pylint: disable=unused-variable
+        from . import signals  # pylint: disable=unused-import
